@@ -3,24 +3,24 @@ package cmd
 import (
 	"strings"
 
-	"github.com/muesli/coral"
-	"github.com/muesli/coral/doc"
+	"github.com/spf13/cobra"
+	"github.com/spf13/cobra/doc"
 )
 
 type docsCmd struct {
-	cmd *coral.Command
+	cmd *cobra.Command
 }
 
 func newDocsCmd() *docsCmd {
 	root := &docsCmd{}
-	cmd := &coral.Command{
+	cmd := &cobra.Command{
 		Use:                   "docs",
 		Short:                 "Generates GoReleaser's command line docs",
 		SilenceUsage:          true,
 		DisableFlagsInUseLine: true,
 		Hidden:                true,
-		Args:                  coral.NoArgs,
-		RunE: func(cmd *coral.Command, args []string) error {
+		Args:                  cobra.NoArgs,
+		RunE: func(cmd *cobra.Command, args []string) error {
 			root.cmd.Root().DisableAutoGenTag = true
 			return doc.GenMarkdownTreeCustom(root.cmd.Root(), "www/docs/cmd", func(_ string) string {
 				return ""
