@@ -119,7 +119,7 @@ func TestReleaseFlags(t *testing.T) {
 
 	t.Run("rm dist", func(t *testing.T) {
 		require.True(t, setup(t, releaseOpts{
-			rmDist: true,
-		}).RmDist)
+			clean: true,
+		}).Clean)
 	})
 }
